@@ -13,9 +13,8 @@
 //---------------------------------------------------------------------------
 #include "Core.h"
 #include "Common/Schema.h"
-#include "Database.h"
-#include "NoDatabase.h"
-#include "SQLLite.h"
+#include "NoDatabaseReport.h"
+#include "SQLLiteReport.h"
 #include "Configuration.h"
 #include "Json.h"
 #include "Common/Schematron.h"
@@ -158,13 +157,13 @@ void Core::load_database()
     if (!config || config->get("SQLite_Path", db_path) < 0)
         db_path = get_database_path();
 
-    db = new SQLLite;
+    db = new SQLLiteReport;
 
-    db->set_database_directory(db_path);
+    ((Database*)db)->set_database_directory(db_path);
     db->set_database_filename(database_name);
     db->init_report();
 #else
-    db = new NoDatabase;
+    db = new NoDatabaseReport;
     db->init_report();
 #endif
 }
@@ -276,12 +275,9 @@ const std::map<std::string, Plugin*>& Core::get_format_plugins() const
 //***************************************************************************
 
 //---------------------------------------------------------------------------
-int Core::open_file(const std::string& file, bool& registered, bool force_analyze)
+int Core::open_file(const std::string& file, bool& registered,
+                    const std::vector<std::string>& options, bool force_analyze)
 {
-    //TODO: When ZenLib will manage network files
-    // if (!ZenLib::File::Exists(Ztring().From_UTF8(file)))
-    //     return -1;
-
     registered = false;
     if (!force_analyze)
         registered = file_is_registered(file);
@@ -289,7 +285,7 @@ int Core::open_file(const std::string& file, bool& registered, bool force_analyz
     if (!registered)
     {
         if (get_db())
-            scheduler->add_element_to_queue(file);
+            scheduler->add_element_to_queue(file, options);
         else
             MI->Open(Ztring().From_UTF8(file));
     }
@@ -958,6 +954,12 @@ std::string Core::get_last_modification_file(const std::string& filename)
     return time.To_UTF8();
 }
 
+//---------------------------------------------------------------------------
+bool Core::file_is_existing(const std::string& filename)
+{
+    return ZenLib::File::Exists(Ztring().From_UTF8(filename));
+}
+
 //---------------------------------------------------------------------------
 void Core::register_report_xml_to_database(std::string& file, const std::string& time,
                                            const std::string& report,
@@ -1428,17 +1430,28 @@ bool Core::file_is_registered_in_db(const std::string& filename)
         return false;
 
     std::string time = get_last_modification_file(filename);
+    bool is_existing = file_is_existing(filename);
 
     db_mutex.Enter();
-    bool res = db->file_is_registered(MediaConchLib::report_MediaInfo,
-                                      MediaConchLib::format_Xml, filename, time);
+    bool res;
+    if (is_existing)
+        res = db->file_is_registered(MediaConchLib::report_MediaInfo,
+                                     MediaConchLib::format_Xml, filename, time);
+    else
+        res = db->file_is_registered(MediaConchLib::report_MediaInfo,
+                                     MediaConchLib::format_Xml, filename);
 
     if (!res)
     {
         MediaConchLib::report report_kind;
         db->get_element_report_kind(filename, report_kind);
         if (report_kind != MediaConchLib::report_MediaConch)
-            res = db->file_is_registered(report_kind, MediaConchLib::format_Xml, filename, time);
+        {
+            if (is_existing)
+                res = db->file_is_registered(report_kind, MediaConchLib::format_Xml, filename, time);
+            else
+                res = db->file_is_registered(report_kind, MediaConchLib::format_Xml, filename);
+        }
     }
 
     db_mutex.Leave();
@@ -1610,7 +1623,7 @@ bool Core::database_is_enabled() const
 }
 
 //---------------------------------------------------------------------------
-Database *Core::get_db()
+DatabaseReport *Core::get_db()
 {
     if (!db)
         load_database();
